/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.cli.command;

import org.ow2.petals.cli.api.command.CommandUtil;
import org.ow2.petals.cli.api.command.DisconnectionCommand;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandTooManyArgumentsException;
import org.ow2.petals.cli.api.command.exception.DisconnectionErrorException;
import org.ow2.petals.cli.command.AbstractCommand;
import org.ow2.petals.registry.client.api.exception.ConnectionErrorException;

/**
 * The disconnection command
 * 
 * @author Christophe DENEUX - Linagora
 */
public class Disconnect extends AbstractCommand implements DisconnectionCommand {

    public Disconnect() {
        super();
        this.setUsage(CommandUtil.formatCommandUsage(this));
        this.setDescription("Disconnect from a Petals Registry cluster");
    }

    @Override
    public void doExecute(final String[] args) throws CommandException {
        if (!this.checkArguments(args, 0, 0)) {
            throw new CommandTooManyArgumentsException(this, args);
        }

        this.disconnect();
        this.getShell().setDefaultPrompt();

    }

    @Override
    public void disconnect() throws DisconnectionErrorException, CommandException {

        try {
            if (this.isConnected()) {
                Connect.PETALS_REGISTRY_CLIENT.disconnect();
                Connect.PETALS_REGISTRY_CLIENT = null;
            }
        } catch (final ConnectionErrorException e) {
            throw new DisconnectionErrorException(this, e);
        }
    }

    @Override
    public boolean isConnected() throws DisconnectionErrorException {
        return Connect.PETALS_REGISTRY_CLIENT != null;
    }

}