/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.cli.command;

import java.net.UnknownHostException;
import java.util.HashMap;
import java.util.Map;

import org.ow2.petals.cli.api.connection.ConnectionParameters;
import org.ow2.petals.cli.api.connection.exception.HostMissingException;
import org.ow2.petals.cli.api.connection.exception.InvalidPortException;
import org.ow2.petals.cli.api.connection.exception.PasswordMissingException;
import org.ow2.petals.cli.api.connection.exception.UsernameMissingException;
import org.ow2.petals.cli.api.pref.PreferenceFileException;
import org.ow2.petals.cli.api.pref.Preferences;
import org.ow2.petals.cli.api.pref.exception.MissingDefaultPreferenceFileException;
import org.ow2.petals.cli.api.pref.exception.PreferenceFileNotFoundException;
import org.ow2.petals.registry.cli.connection.AuthenticatedConnectionParametersImpl;

/**
 * Abstract class with useful method for command test.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class AbstractArtifactCommandTest {

    /**
     * Create a basic preference configuration
     * 
     * @param host
     * @param port
     * @param group
     * @param password
     * @return A basic preference configuration
     */
    protected Preferences createBasicPreferences(final String host, final int port, final String groupname,
            final String password) {

        try {
            final ConnectionParameters connectionParameters = new AuthenticatedConnectionParametersImpl(host, port,
                    groupname, password);
            return new Preferences() {

                @Override
                public void intializePreferenceParameters() throws MissingDefaultPreferenceFileException,
                        PreferenceFileNotFoundException, PreferenceFileException {
                    // NOP
                }

                @Override
                public Map<String, ConnectionParameters> getPreferenceConnectionParameters() {
                    final Map<String, ConnectionParameters> connectionParametersMap = new HashMap<String, ConnectionParameters>();
                    connectionParametersMap.put("default", connectionParameters);
                    return connectionParametersMap;
                }

                @Override
                public ConnectionParameters getDefaultConnectionParameters() {
                    return connectionParameters;
                }
            };
        } catch (final UnknownHostException e) {
            // NOP: This exception has not to occur
            return null;
        } catch (final HostMissingException e) {
            // NOP: This exception has not to occur
            return null;
        } catch (final InvalidPortException e) {
            // NOP: This exception has not to occur
            return null;
        } catch (final UsernameMissingException e) {
            // NOP: This exception has not to occur
            return null;
        } catch (final PasswordMissingException e) {
            // NOP: This exception has not to occur
            return null;
        }
    }
}
